@@ -23,7 +23,7 @@ import time
 
 import jwt  # package name is PyJWT in setup
 import requests
-import six.moves.urllib.parse as urlparse
+import urllib.parse as urlparse
 
 
 class JWT(object):
@@ -48,9 +48,7 @@ class JWT(object):
 
         # create JSON Web Token
         # noinspection PyUnresolvedReferences
-        jwt_token = jwt.encode(payload, self.key, algorithm='RS256')
-        # decode bytes into string
-        return jwt_token.decode("utf-8")
+        return jwt.encode(payload, self.key, algorithm='RS256')
 
 
 class AccessRequest(object):
